@@ -18,7 +18,6 @@ import warnings
 
 import mlflow
 from mlflow import pyfunc
-from mlflow.entities.run_status import RunStatus
 from mlflow.exceptions import MlflowException
 from mlflow.models import Model
 from mlflow.models.model import MLMODEL_FILE_NAME
@@ -27,13 +26,14 @@ from mlflow.models.utils import ModelInputExample, _save_example
 from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE, INTERNAL_ERROR
 from mlflow.protos.databricks_pb2 import RESOURCE_ALREADY_EXISTS
 from mlflow.tracking.artifact_utils import _download_artifact_from_uri
-from mlflow.utils import gorilla
 from mlflow.utils.annotations import experimental
 from mlflow.utils.environment import _mlflow_conda_env
+from mlflow.utils.mlflow_tags import MLFLOW_AUTOLOGGING
 from mlflow.utils.model_utils import _get_flavor_configuration
 from mlflow.utils.autologging_utils import (
+    autologging_integration,
+    safe_patch,
     try_mlflow_log,
-    wrap_patch,
     INPUT_EXAMPLE_SAMPLE_ROWS,
     resolve_input_example_and_signature,
 )
@@ -56,16 +56,12 @@ def get_default_conda_env(include_cloudpickle=False):
     """
     import sklearn
 
-    pip_deps = None
+    pip_deps = ["scikit-learn=={}".format(sklearn.__version__)]
     if include_cloudpickle:
         import cloudpickle
 
-        pip_deps = ["cloudpickle=={}".format(cloudpickle.__version__)]
-    return _mlflow_conda_env(
-        additional_conda_deps=["scikit-learn={}".format(sklearn.__version__)],
-        additional_pip_deps=pip_deps,
-        additional_conda_channels=None,
-    )
+        pip_deps += ["cloudpickle=={}".format(cloudpickle.__version__)]
+    return _mlflow_conda_env(additional_pip_deps=pip_deps, additional_conda_channels=None)
 
 
 def save_model(
@@ -532,9 +528,18 @@ class _SklearnTrainingSession(object):
 
 
 @experimental
-def autolog(log_input_examples=False, log_model_signatures=True):
+@autologging_integration(FLAVOR_NAME)
+def autolog(
+    log_input_examples=False,
+    log_model_signatures=True,
+    log_models=True,
+    disable=False,
+    exclusive=False,
+    disable_for_unsupported_versions=False,
+    silent=False,
+):  # pylint: disable=unused-argument
     """
-    Enables autologging for scikit-learn estimators.
+    Enables (or disables) and configures autologging for scikit-learn estimators.
 
     **When is autologging performed?**
       Autologging is performed when you call:
@@ -699,11 +704,30 @@ def autolog(log_input_examples=False, log_model_signatures=True):
     :param log_input_examples: If ``True``, input examples from training datasets are collected and
                                logged along with scikit-learn model artifacts during training. If
                                ``False``, input examples are not logged.
+                               Note: Input examples are MLflow model attributes
+                               and are only collected if ``log_models`` is also ``True``.
     :param log_model_signatures: If ``True``,
                                  :py:class:`ModelSignatures <mlflow.models.ModelSignature>`
                                  describing model inputs and outputs are collected and logged along
                                  with scikit-learn model artifacts during training. If ``False``,
                                  signatures are not logged.
+                                 Note: Model signatures are MLflow model attributes
+                                 and are only collected if ``log_models`` is also ``True``.
+    :param log_models: If ``True``, trained models are logged as MLflow model artifacts.
+                       If ``False``, trained models are not logged.
+                       Input examples and model signatures, which are attributes of MLflow models,
+                       are also omitted when ``log_models`` is ``False``.
+    :param disable: If ``True``, disables the scikit-learn autologging integration. If ``False``,
+                    enables the scikit-learn autologging integration.
+    :param exclusive: If ``True``, autologged content is not logged to user-created fluent runs.
+                      If ``False``, autologged content is logged to the active fluent run,
+                      which may be user-created.
+    :param disable_for_unsupported_versions: If ``True``, disable autologging for versions of
+                      scikit-learn that have not been tested against this version of the MLflow
+                      client or are incompatible.
+    :param silent: If ``True``, suppress all event logs and warnings from MLflow during scikit-learn
+                   autologging. If ``False``, show all events and warnings during scikit-learn
+                   autologging.
     """
     import pandas as pd
     import sklearn
@@ -741,32 +765,15 @@ def autolog(log_input_examples=False, log_model_signatures=True):
             stacklevel=2,
         )
 
-    def fit_mlflow(self, clazz, func_name, *args, **kwargs):
+    def fit_mlflow(original, self, *args, **kwargs):
         """
         Autologging function that performs model training by executing the training method
         referred to be `func_name` on the instance of `clazz` referred to by `self` & records
         MLflow parameters, metrics, tags, and artifacts to a corresponding MLflow Run.
         """
-        should_start_run = mlflow.active_run() is None
-        if should_start_run:
-            try_mlflow_log(mlflow.start_run)
-
         _log_pretraining_metadata(self, *args, **kwargs)
-
-        original_fit = gorilla.get_original_attribute(clazz, func_name)
-        try:
-            fit_output = original_fit(self, *args, **kwargs)
-        except Exception as e:
-            if should_start_run:
-                try_mlflow_log(mlflow.end_run, RunStatus.to_string(RunStatus.FAILED))
-
-            raise e
-
+        fit_output = original(self, *args, **kwargs)
         _log_posttraining_metadata(self, *args, **kwargs)
-
-        if should_start_run:
-            try_mlflow_log(mlflow.end_run)
-
         return fit_output
 
     def _log_pretraining_metadata(estimator, *args, **kwargs):  # pylint: disable=unused-argument
@@ -814,7 +821,7 @@ def autolog(log_input_examples=False, log_model_signatures=True):
             try:
                 score_args = _get_args_for_score(estimator.score, estimator.fit, args, kwargs)
                 training_score = estimator.score(*score_args)
-            except Exception as e:  # pylint: disable=broad-except
+            except Exception as e:
                 msg = (
                     estimator.score.__qualname__
                     + " failed. The 'training_score' metric will not be recorded. Scoring error: "
@@ -846,24 +853,26 @@ def autolog(log_input_examples=False, log_model_signatures=True):
 
             return infer_signature(input_example, estimator.predict(input_example))
 
-        input_example, signature = resolve_input_example_and_signature(
-            get_input_example,
-            infer_model_signature,
-            log_input_examples,
-            log_model_signatures,
-            _logger,
-        )
+        if log_models:
+            # Will only resolve `input_example` and `signature` if `log_models` is `True`.
+            input_example, signature = resolve_input_example_and_signature(
+                get_input_example,
+                infer_model_signature,
+                log_input_examples,
+                log_model_signatures,
+                _logger,
+            )
 
-        try_mlflow_log(
-            log_model,
-            estimator,
-            artifact_path="model",
-            signature=signature,
-            input_example=input_example,
-        )
+            try_mlflow_log(
+                log_model,
+                estimator,
+                artifact_path="model",
+                signature=signature,
+                input_example=input_example,
+            )
 
         if _is_parameter_search_estimator(estimator):
-            if hasattr(estimator, "best_estimator_"):
+            if hasattr(estimator, "best_estimator_") and log_models:
                 try_mlflow_log(
                     log_model,
                     estimator.best_estimator_,
@@ -886,13 +895,14 @@ def autolog(log_input_examples=False, log_model_signatures=True):
                 try:
                     # Fetch environment-specific tags (e.g., user and source) to ensure that lineage
                     # information is consistent with the parent run
-                    environment_tags = context_registry.resolve_tags()
+                    child_tags = context_registry.resolve_tags()
+                    child_tags.update({MLFLOW_AUTOLOGGING: FLAVOR_NAME})
                     _create_child_runs_for_parameter_search(
                         cv_estimator=estimator,
                         parent_run=mlflow.active_run(),
-                        child_tags=environment_tags,
+                        child_tags=child_tags,
                     )
-                except Exception as e:  # pylint: disable=broad-except
+                except Exception as e:
 
                     msg = (
                         "Encountered exception during creation of child runs for parameter search."
@@ -905,7 +915,7 @@ def autolog(log_input_examples=False, log_model_signatures=True):
                     _log_parameter_search_results_as_artifact(
                         cv_results_df, mlflow.active_run().info.run_id
                     )
-                except Exception as e:  # pylint: disable=broad-except
+                except Exception as e:
 
                     msg = (
                         "Failed to log parameter search results as an artifact."
@@ -913,7 +923,7 @@ def autolog(log_input_examples=False, log_model_signatures=True):
                     )
                     _logger.warning(msg)
 
-    def patched_fit(self, clazz, func_name, *args, **kwargs):
+    def patched_fit(original, self, *args, **kwargs):
         """
         Autologging patch function to be applied to a sklearn model class that defines a `fit`
         method and inherits from `BaseEstimator` (thereby defining the `get_params()` method)
@@ -924,18 +934,11 @@ def autolog(log_input_examples=False, log_model_signatures=True):
                           for autologging (e.g., specify "fit" in order to indicate that
                           `sklearn.linear_model.LogisticRegression.fit()` is being patched)
         """
-        with _SklearnTrainingSession(clazz=clazz, allow_children=False) as t:
+        with _SklearnTrainingSession(clazz=self.__class__, allow_children=False) as t:
             if t.should_log():
-                return fit_mlflow(self, clazz, func_name, *args, **kwargs)
+                return fit_mlflow(original, self, *args, **kwargs)
             else:
-                original_fit = gorilla.get_original_attribute(clazz, func_name)
-                return original_fit(self, *args, **kwargs)
-
-    def create_patch_func(clazz, func_name):
-        def f(self, *args, **kwargs):
-            return patched_fit(self, clazz, func_name, *args, **kwargs)
-
-        return f
+                return original(self, *args, **kwargs)
 
     _, estimators_to_patch = zip(*_all_estimators())
     # Ensure that relevant meta estimators (e.g. GridSearchCV, Pipeline) are selected
@@ -988,5 +991,6 @@ def autolog(log_input_examples=False, log_model_signatures=True):
                 if isinstance(original, property):
                     continue
 
-                patch_func = create_patch_func(class_def, func_name)
-                wrap_patch(class_def, func_name, patch_func)
+                safe_patch(
+                    FLAVOR_NAME, class_def, func_name, patched_fit, manage_run=True,
+                )
