@@ -8,8 +8,6 @@ import atexit
 import time
 import logging
 import inspect
-import numpy as np
-import pandas as pd
 
 from mlflow.entities import Run, RunStatus, Param, RunTag, Metric, ViewType
 from mlflow.entities.lifecycle_stage import LifecycleStage
@@ -19,26 +17,18 @@ from mlflow.tracking import artifact_utils, _get_store
 from mlflow.tracking.context import registry as context_registry
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 from mlflow.utils import env
-from mlflow.utils.autologging_utils import _is_testing, autologging_integration
+from mlflow.utils.autologging_utils import (
+    _is_testing,
+    autologging_integration,
+    AUTOLOGGING_INTEGRATIONS,
+    autologging_is_disabled,
+)
 from mlflow.utils.databricks_utils import is_in_databricks_notebook, get_notebook_id
 from mlflow.utils.import_hooks import register_post_import_hook
 from mlflow.utils.mlflow_tags import MLFLOW_PARENT_RUN_ID, MLFLOW_RUN_NAME
 from mlflow.utils.validation import _validate_run_id
 from mlflow.utils.annotations import experimental
 
-from mlflow import (
-    tensorflow,
-    keras,
-    gluon,
-    xgboost,
-    lightgbm,
-    statsmodels,
-    spark,
-    sklearn,
-    fastai,
-    pytorch,
-)
-
 _EXPERIMENT_ID_ENV_VAR = "MLFLOW_EXPERIMENT_ID"
 _EXPERIMENT_NAME_ENV_VAR = "MLFLOW_EXPERIMENT_NAME"
 _RUN_ID_ENV_VAR = "MLFLOW_RUN_ID"
@@ -141,6 +131,7 @@ def start_run(run_id=None, experiment_id=None, run_name=None, nested=False, tags
                      Used only when ``run_id`` is unspecified.
     :param nested: Controls whether run is nested in parent run. ``True`` creates a nested run.
     :param tags: An optional dictionary of string keys and values to set as tags on the new run.
+                 If an existing run is being resumed, this argument is ignored.
     :return: :py:class:`mlflow.ActiveRun` object that acts as a context manager wrapping
              the run's state.
 
@@ -955,6 +946,7 @@ def search_runs(
     run_view_type=ViewType.ACTIVE_ONLY,
     max_results=SEARCH_MAX_RESULTS_PANDAS,
     order_by=None,
+    output_format="pandas",
 ):
     """
     Get a pandas DataFrame of runs that fit the search criteria.
@@ -968,11 +960,16 @@ def search_runs(
     :param order_by: List of columns to order by (e.g., "metrics.rmse"). The ``order_by`` column
                      can contain an optional ``DESC`` or ``ASC`` value. The default is ``ASC``.
                      The default ordering is to sort by ``start_time DESC``, then ``run_id``.
+    :param output_format: The output format to be returned. If ``pandas``, a ``pandas.DataFrame``
+                          is returned and, if ``list``, a list of :py:class:`mlflow.entities.Run`
+                          is returned.
 
-    :return: A pandas.DataFrame of runs, where each metric, parameter, and tag
-        are expanded into their own columns named metrics.*, params.*, and tags.*
-        respectively. For runs that don't have a particular metric, parameter, or tag, their
-        value will be (NumPy) Nan, None, or None respectively.
+    :return: If output_format is ``list``: a list of :py:class:`mlflow.entities.Run`. If
+             output_format is ``pandas``: ``pandas.DataFrame`` of runs, where each metric,
+             parameter, and tag is expanded into its own column named metrics.*, params.*, or
+             tags.* respectively. For runs that don't have a particular metric, parameter, or tag,
+             the value for the corresponding column is (NumPy) ``Nan``, ``None``, or ``None``
+             respectively.
 
     .. code-block:: python
         :caption: Example
@@ -1016,74 +1013,85 @@ def search_runs(
     # full thing is a mess
     def pagination_wrapper_func(number_to_get, next_page_token):
         return MlflowClient().search_runs(
-            experiment_ids, filter_string, run_view_type, number_to_get, order_by, next_page_token
+            experiment_ids, filter_string, run_view_type, number_to_get, order_by, next_page_token,
         )
 
     runs = _paginate(pagination_wrapper_func, NUM_RUNS_PER_PAGE_PANDAS, max_results)
 
-    info = {
-        "run_id": [],
-        "experiment_id": [],
-        "status": [],
-        "artifact_uri": [],
-        "start_time": [],
-        "end_time": [],
-    }
-    params, metrics, tags = ({}, {}, {})
-    PARAM_NULL, METRIC_NULL, TAG_NULL = (None, np.nan, None)
-    for i, run in enumerate(runs):
-        info["run_id"].append(run.info.run_id)
-        info["experiment_id"].append(run.info.experiment_id)
-        info["status"].append(run.info.status)
-        info["artifact_uri"].append(run.info.artifact_uri)
-        info["start_time"].append(pd.to_datetime(run.info.start_time, unit="ms", utc=True))
-        info["end_time"].append(pd.to_datetime(run.info.end_time, unit="ms", utc=True))
+    if output_format == "list":
+        return runs  # List[mlflow.entities.run.Run]
+    elif output_format == "pandas":
+        import numpy as np
+        import pandas as pd
 
-        # Params
-        param_keys = set(params.keys())
-        for key in param_keys:
-            if key in run.data.params:
-                params[key].append(run.data.params[key])
-            else:
-                params[key].append(PARAM_NULL)
-        new_params = set(run.data.params.keys()) - param_keys
-        for p in new_params:
-            params[p] = [PARAM_NULL] * i  # Fill in null values for all previous runs
-            params[p].append(run.data.params[p])
+        info = {
+            "run_id": [],
+            "experiment_id": [],
+            "status": [],
+            "artifact_uri": [],
+            "start_time": [],
+            "end_time": [],
+        }
+        params, metrics, tags = ({}, {}, {})
+        PARAM_NULL, METRIC_NULL, TAG_NULL = (None, np.nan, None)
+        for i, run in enumerate(runs):
+            info["run_id"].append(run.info.run_id)
+            info["experiment_id"].append(run.info.experiment_id)
+            info["status"].append(run.info.status)
+            info["artifact_uri"].append(run.info.artifact_uri)
+            info["start_time"].append(pd.to_datetime(run.info.start_time, unit="ms", utc=True))
+            info["end_time"].append(pd.to_datetime(run.info.end_time, unit="ms", utc=True))
 
-        # Metrics
-        metric_keys = set(metrics.keys())
-        for key in metric_keys:
-            if key in run.data.metrics:
-                metrics[key].append(run.data.metrics[key])
-            else:
-                metrics[key].append(METRIC_NULL)
-        new_metrics = set(run.data.metrics.keys()) - metric_keys
-        for m in new_metrics:
-            metrics[m] = [METRIC_NULL] * i
-            metrics[m].append(run.data.metrics[m])
+            # Params
+            param_keys = set(params.keys())
+            for key in param_keys:
+                if key in run.data.params:
+                    params[key].append(run.data.params[key])
+                else:
+                    params[key].append(PARAM_NULL)
+            new_params = set(run.data.params.keys()) - param_keys
+            for p in new_params:
+                params[p] = [PARAM_NULL] * i  # Fill in null values for all previous runs
+                params[p].append(run.data.params[p])
 
-        # Tags
-        tag_keys = set(tags.keys())
-        for key in tag_keys:
-            if key in run.data.tags:
-                tags[key].append(run.data.tags[key])
-            else:
-                tags[key].append(TAG_NULL)
-        new_tags = set(run.data.tags.keys()) - tag_keys
-        for t in new_tags:
-            tags[t] = [TAG_NULL] * i
-            tags[t].append(run.data.tags[t])
+            # Metrics
+            metric_keys = set(metrics.keys())
+            for key in metric_keys:
+                if key in run.data.metrics:
+                    metrics[key].append(run.data.metrics[key])
+                else:
+                    metrics[key].append(METRIC_NULL)
+            new_metrics = set(run.data.metrics.keys()) - metric_keys
+            for m in new_metrics:
+                metrics[m] = [METRIC_NULL] * i
+                metrics[m].append(run.data.metrics[m])
 
-    data = {}
-    data.update(info)
-    for key in metrics:
-        data["metrics." + key] = metrics[key]
-    for key in params:
-        data["params." + key] = params[key]
-    for key in tags:
-        data["tags." + key] = tags[key]
-    return pd.DataFrame(data)
+            # Tags
+            tag_keys = set(tags.keys())
+            for key in tag_keys:
+                if key in run.data.tags:
+                    tags[key].append(run.data.tags[key])
+                else:
+                    tags[key].append(TAG_NULL)
+            new_tags = set(run.data.tags.keys()) - tag_keys
+            for t in new_tags:
+                tags[t] = [TAG_NULL] * i
+                tags[t].append(run.data.tags[t])
+
+        data = {}
+        data.update(info)
+        for key in metrics:
+            data["metrics." + key] = metrics[key]
+        for key in params:
+            data["params." + key] = params[key]
+        for key in tags:
+            data["tags." + key] = tags[key]
+        return pd.DataFrame(data)
+    else:
+        raise ValueError(
+            "Unsupported output format: %s. Supported string values are 'pandas' or 'list'"
+            % output_format
+        )
 
 
 def list_run_infos(
@@ -1218,6 +1226,8 @@ def autolog(
     log_models=True,
     disable=False,
     exclusive=False,
+    disable_for_unsupported_versions=False,
+    silent=False,
 ):  # pylint: disable=unused-argument
     """
     Enables (or disables) and configures autologging for all supported integrations.
@@ -1227,6 +1237,29 @@ def autolog(
     See the :ref:`tracking docs <automatic-logging>` for a list of supported autologging
     integrations.
 
+    Note that framework-specific configurations set at any point will take precedence over
+    any configurations set by this function. For example:
+
+    .. code-block:: python
+
+        mlflow.autolog(log_models=False, exclusive=True)
+        import sklearn
+
+    would enable autologging for `sklearn` with `log_models=False` and `exclusive=True`,
+    but
+
+    .. code-block:: python
+
+        mlflow.autolog(log_models=False, exclusive=True)
+        import sklearn
+        mlflow.sklearn.autolog(log_models=True)
+
+    would enable autologging for `sklearn` with `log_models=True` and `exclusive=False`,
+    the latter resulting from the default value for `exclusive` in `mlflow.sklearn.autolog`;
+    other framework autolog functions (e.g. `mlflow.tensorflow.autolog`) would use the
+    configurations set by `mlflow.autolog` (in this instance, `log_models=False`, `exclusive=True`),
+    until they are explicitly called by the user.
+
     :param log_input_examples: If ``True``, input examples from training datasets are collected and
                                logged along with model artifacts during training. If ``False``,
                                input examples are not logged.
@@ -1247,6 +1280,12 @@ def autolog(
     :param exclusive: If ``True``, autologged content is not logged to user-created fluent runs.
                       If ``False``, autologged content is logged to the active fluent run,
                       which may be user-created.
+    :param disable_for_unsupported_versions: If ``True``, disable autologging for versions of
+                      all integration libraries that have not been tested against this version
+                      of the MLflow client or are incompatible.
+    :param silent: If ``True``, suppress all event logs and warnings from MLflow during autologging
+                   setup and training execution. If ``False``, show all events and warnings during
+                   autologging setup and training execution.
 
     .. code-block:: python
         :caption: Example
@@ -1295,6 +1334,19 @@ def autolog(
         tags: {'estimator_class': 'sklearn.linear_model._base.LinearRegression',
                'estimator_name': 'LinearRegression'}
     """
+    from mlflow import (
+        tensorflow,
+        keras,
+        gluon,
+        xgboost,
+        lightgbm,
+        statsmodels,
+        spark,
+        sklearn,
+        fastai,
+        pytorch,
+    )
+
     locals_copy = locals().items()
 
     # Mapping of library module name to specific autolog function
@@ -1314,25 +1366,49 @@ def autolog(
         "pytorch_lightning": pytorch.autolog,
     }
 
+    CONF_KEY_IS_GLOBALLY_CONFIGURED = "globally_configured"
+
     def get_autologging_params(autolog_fn):
         try:
             needed_params = list(inspect.signature(autolog_fn).parameters.keys())
             return {k: v for k, v in locals_copy if k in needed_params}
-        except Exception:  # pylint: disable=broad-except
+        except Exception:
             return {}
 
     def setup_autologging(module):
         try:
             autolog_fn = LIBRARY_TO_AUTOLOG_FN[module.__name__]
+
+            # Only call integration's autolog function with `mlflow.autolog` configs
+            # if the integration's autolog function has not already been called by the user.
+            # Logic is as follows:
+            # - if a previous_config exists, that means either `mlflow.autolog` or
+            #   `mlflow.integration.autolog` was called.
+            # - if the config contains `CONF_KEY_IS_GLOBALLY_CONFIGURED`, the configuration
+            #   was set by `mlflow.autolog`, and so we can safely call `autolog_fn` with
+            #   `autologging_params`.
+            # - if the config doesn't contain this key, the configuration was set by an
+            #   `mlflow.integration.autolog` call, so we should not call `autolog_fn` with
+            #   new configs.
+            prev_config = AUTOLOGGING_INTEGRATIONS.get(autolog_fn.integration_name)
+            if prev_config and not prev_config.get(CONF_KEY_IS_GLOBALLY_CONFIGURED, False):
+                return
+
             autologging_params = get_autologging_params(autolog_fn)
             autolog_fn(**autologging_params)
-            _logger.info("Autologging successfully enabled for %s.", module.__name__)
-        except Exception as e:  # pylint: disable=broad-except
+            AUTOLOGGING_INTEGRATIONS[autolog_fn.integration_name][
+                CONF_KEY_IS_GLOBALLY_CONFIGURED
+            ] = True
+            if not autologging_is_disabled(
+                autolog_fn.integration_name
+            ) and not autologging_params.get("silent", False):
+                _logger.info("Autologging successfully enabled for %s.", module.__name__)
+        except Exception as e:
             if _is_testing():
                 # Raise unexpected exceptions in test mode in order to detect
                 # errors within dependent autologging integrations
                 raise
-            else:
+            elif not autologging_params.get("silent", False):
                 _logger.warning(
                     "Exception raised while enabling autologging for %s: %s",
                     module.__name__,
@@ -1356,7 +1432,7 @@ def autolog(
         #   of their session so we want to enable autologging once they do
         if "pyspark" in str(ie):
             register_post_import_hook(setup_autologging, "pyspark", overwrite=True)
-    except Exception as e:  # pylint: disable=broad-except
+    except Exception as e:
         if _is_testing():
             # Raise unexpected exceptions in test mode in order to detect
             # errors within dependent autologging integrations
